@@ -1,7 +1,7 @@
 use Chart::PNGgraph::lines;
-use Chart::PNGgraph::colour;
+use GD::Graph::colour;
 
-Chart::PNGgraph::colour::read_rgb("rgb.txt") or 
+GD::Graph::colour::read_rgb("rgb.txt") or 
 	die "Cannot read colours from rgb.txt";
 
 print STDERR "Processing sample 5-3\n";
